Skip to contents

Internal Function: Called within the metadata_map function.

It displays data properties to the user and requests a categorisation into a domain.

An optional note can be included with the categorisation.

Usage

user_categorisation(var, desc, type, domain_code_max)

Arguments

var

Name of the variable

desc

Description of the variable

type

Data type of the variable

domain_code_max

Max code in the domain list (0-3 auto included, then N included via domain_file)

Value

It returns a list containing the decision and decision note