Internal Function: Called within the metadata_map function.
It displays data properties to the user and requests a categorisation into
a domain.
An optional note can be included with the categorisation.
See also
Other metadata_map_internal:
data_load(),
empty_count(),
empty_plot(),
end_plot(),
output_copy(),
user_categorisation_loop()
Other map_compare_internal:
consensus_on_mismatch(),
valid_comparison()